BooleanContext

Struct BooleanContext 

pub struct BooleanContext(Void);
Implementor of SubstParseContext for booleans

No values of this type are ever created - it’s just a generic parameter, used to select the associated marker types (and their constructor methods( in SubstParseContext.

So it can be uninhabited.

Tuple Fields

0: Void