pub struct BooleanContext(Void);Expand description
Implementor of SubstParseContext for booleans
No values of this type are ever created - it’s just a generic parameter, used to select the associated marker types (and their constructor methods( in SubstParseContext.
So it can be uninhabited.
Tuple Fields
0: VoidTrait Implementations
Sourceimpl Debug for BooleanContext
impl Debug for BooleanContext
Sourceimpl SubstParseContext for BooleanContext
impl SubstParseContext for BooleanContext
Sourcetype NotInPaste = ()
type NotInPaste = ()
Uninhabited iff this lexical context is within
${paste }Sourcetype NotInConcat = ()
type NotInConcat = ()
Uninhabited iff this lexical context is within
${concat }Sourcetype ConcatOnly = Void
type ConcatOnly = Void
Uninhabited unless this lexical context is within
${concat }Sourcetype DbgContent = Subst<BooleanContext>
type DbgContent = Subst<BooleanContext>
Content of the
dbg keyword Read moreSourcetype SpecialParseContext = ()
type SpecialParseContext = ()
For communicating through
parse_special Read morefn not_in_paste(_: &impl Spanned) -> Result<()>
fn not_in_concat(_: &impl Spanned) -> Result<()>
fn bool_only(_: &impl Spanned) -> Result<()>
Sourcefn meta_recog_usage(_: &SubstMeta<Self>) -> UsageInfo<IsUsed>
fn meta_recog_usage(_: &SubstMeta<Self>) -> UsageInfo<IsUsed>
When we find a
fmeta etc. in this context, does it allow a value? Read morefn not_in_bool(span: &impl Spanned) -> Result<Void>
Sourcefn missing_keyword_arguments(kw_span: Span) -> Result<Void>
fn missing_keyword_arguments(kw_span: Span) -> Result<Void>
Return an error suitable for reporting missing arguments Read more
fn concat_only(span: &impl Spanned) -> Result<Self::ConcatOnly>
Sourcefn parse_maybe_within_parens<T>(
input: ParseStream<'_>,
f: impl FnOnce(ParseStream<'_>) -> Result<T>,
) -> Result<T>
fn parse_maybe_within_parens<T>( input: ParseStream<'_>, f: impl FnOnce(ParseStream<'_>) -> Result<T>, ) -> Result<T>
Parse using
f, within parens in boolean context, not otherwise Read moreSourcefn parse_maybe_comma(input: ParseStream<'_>) -> Result<()>
fn parse_maybe_comma(input: ParseStream<'_>) -> Result<()>
Parse maybe a comma (comma in boolean contegxt, not otherwise) Read more